@@ -16,6 +16,10 @@ class RibbonStyle(IntEnum):
     Debug = 1
 
 
+Debug = RibbonStyle.Debug
+Default = RibbonStyle.Default
+
+
 class RibbonBar(QtWidgets.QMenuBar):
     """The RibbonBar class is the top level widget that contains the ribbon.
     """
@@ -365,7 +369,7 @@ class RibbonBar(QtWidgets.QMenuBar):
         titles: typing.List[str],
         color: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor] = None,
     ) -> RibbonContextCategories:
-        """Add a new context category to the ribbon.
+        """Add a group of context categories with the same tab color to the ribbon.
 
         :param name: The name of the context categories.
         :param titles: The title of the category.
