@@ -79,10 +79,11 @@ class RibbonTabBar(QtWidgets.QTabBar):
         :param titles: The titles of the tabs to remove.
         """
         for title in titles:
-            self.removeTab(self.indexOf(title))
-            del self._tabColors[title]
-            if title in self._associated_tabs:
-                del self._associated_tabs[title]
+            if title in self.tabTitles():
+                self.removeTab(self.indexOf(title))
+                del self._tabColors[title]
+                if title in self._associated_tabs:
+                    del self._associated_tabs[title]
 
     def currentTabColor(self) -> QtGui.QColor:
         """Current tab color
@@ -98,7 +99,7 @@ class RibbonTabBar(QtWidgets.QTabBar):
         :param color: The color of the tab.
         """
         if self.currentIndex() > 0:
-            rect.setLeft(rect.left())
+            rect.setRight(rect.right() + 5)
 
         rect.setHeight(self.height() - 1)
         rect.setTop(self._contextCategoryTopMargin)
